@@ -111,7 +111,7 @@ def verify_directory(dir):
     while not os.access(dir, os.F_OK):
         try:
             tries += 1
-            os.makedirs(dir, 0750)
+            os.makedirs(dir)
         except:
             if tries > 5:
                 raise
@@ -128,20 +128,25 @@ def deprecated(func, message):
     deprecated_method.__doc__ = "%s\n\n%s" % (message, func.__doc__)
     return deprecated_method
 
-class ThreadLocal(_tlocal):
+class ThreadLocal(object):
     """stores a value on a per-thread basis"""
+
+    __slots__ = '_tlocal'
+
+    def __init__(self):
+        self._tlocal = _tlocal()
     
     def put(self, value):
-        self.value = value
+        self._tlocal.value = value
     
     def has(self):
-        return hasattr(self, 'value')
+        return hasattr(self._tlocal, 'value')
             
     def get(self, default=None):
-        return getattr(self, 'value', default)
+        return getattr(self._tlocal, 'value', default)
             
     def remove(self):
-        del self.value
+        del self._tlocal.value
     
 class SyncDict(object):
     """
@@ -151,8 +156,8 @@ class SyncDict(object):
     
         exists && isvalid ? get : create
 
-    Works with weakref dictionaries and the LRUCache to handle items
-    asynchronously disappearing from the dictionary.  
+    Designed to work with weakref dictionaries to expect items
+    to asynchronously disappear from the dictionary.  
 
     Use python 2.3.3 or greater !  a major bug was just fixed in Nov.
     2003 that was driving me nuts with garbage collection/weakrefs in
@@ -251,6 +256,8 @@ def verify_options(opt, types, error):
                 break
         if not coerced:
             raise Exception(error)
+    elif isinstance(opt, str) and not opt.strip():
+        raise Exception("Empty strings are invalid for: %s" % error)
     return opt
 
 
@@ -304,12 +311,15 @@ def coerce_cache_params(params):
     return verify_rules(params, rules)
 
 
-def parse_cache_config_options(config):
+def parse_cache_config_options(config, include_defaults=True):
     """Parse configuration options and validate for use with the
     CacheManager"""
     # Load default cache options
-    options= dict(type='memory', data_dir=None, expire=None, 
-                       log_file=None)
+    if include_defaults:
+        options= dict(type='memory', data_dir=None, expire=None, 
+                           log_file=None)
+    else:
+        options = {}
     for key, val in config.iteritems():
         if key.startswith('beaker.cache.'):
             options[key[13:]] = val
